web-framework-markdown 0.0.1

An abstract API to create markdown components in any rust framework
docs.rs failed to build web-framework-markdown-0.0.1
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.